compute_qtc: Compute Corrected QT

View source: R/derive_param_qtc.R

compute_qtcR Documentation

Compute Corrected QT

Description

Computes corrected QT using Bazett's, Fridericia's or Sagie's formula.

Usage

compute_qtc(qt, rr, method)

Arguments

qt

QT interval

A numeric vector is expected. It is expected that QT is measured in ms or msec.

rr

RR interval

A numeric vector is expected. It is expected that RR is measured in ms or msec.

method

Method used to QT correction

Details

Depending on the chosen method one of the following formulae is used.

Bazett:

\frac{QT}{\sqrt{\frac{RR}{1000}}}

Fridericia:

\frac{QT}{\sqrt[3]{\frac{RR}{1000}}}

Sagie:

1000\left(\frac{QT}{1000} + 0.154\left(1 - \frac{RR}{1000}\right)\right)

Usually this computation function can not be used with ⁠%>%⁠.

Value

QT interval in ms

See Also

derive_param_qtc()

BDS-Findings Functions that returns a vector: compute_bmi(), compute_bsa(), compute_egfr(), compute_framingham(), compute_map(), compute_qual_imputation(), compute_qual_imputation_dec(), compute_rr(), compute_scale(), transform_range()

Examples

compute_qtc(qt = 350, rr = 857, method = "Bazett")

compute_qtc(qt = 350, rr = 857, method = "Fridericia")

compute_qtc(qt = 350, rr = 857, method = "Sagie")

admiral documentation built on May 28, 2026, 9:08 a.m.