Get list of records not mapped from the lookup table.
See also
Utilities used within Derivation functions:
as_admiral_df(),
extract_unit(),
get_flagged_records(),
get_vars_query()
Get list of records not mapped from the lookup table.
Utilities used within Derivation functions:
as_admiral_df(),
extract_unit(),
get_flagged_records(),
get_vars_query()