View source: R/create_query_data.R
| assert_terms | R Documentation |
The function checks the requirements for terms for queries provided by the user. The terms could have been provided directly in the query definition or via a user provided function for accessing a SMQ or SDG database.
assert_terms(terms, expect_grpname = FALSE, expect_grpid = FALSE, source_text)
terms |
Terms provided by user |
expect_grpname |
Is the |
expect_grpid |
Is the |
source_text |
Text describing the source of the terms, e.g., |
An error is issued if
terms is not a data frame,
terms has zero observations,
the SRCVAR variable is not in terms,
neither the TERMCHAR nor the TERMNUM variable is in terms,
expect_grpname == TRUE and the GRPNAME variable is not in terms,
expect_grpid == TRUE and the GRPID variable is not in terms,
try(
assert_terms(
terms = 42,
source_text = "object provided by the `definition` element"
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.