View source: R/derive_vars_dtm.R
| compute_tmf | R Documentation |
Derive the time imputation flag (*TMF) comparing a date character vector
(--DTC) with a Datetime vector (*DTM).
compute_tmf(dtc, dtm, ignore_seconds_flag = TRUE)
dtc |
The date character vector ( A character date is expected in a format like |
dtm |
The Date vector to compare ( A datetime object is expected. |
ignore_seconds_flag |
ADaM IG states that given SDTM ( By default it is assumed that no seconds are collected and The default value of |
Usually this computation function can not be used with %>%.
The time imputation flag (*TMF) (character value of "H", "M" , "S" or NA)
Date/Time Computation Functions that returns a vector:
compute_age_years(),
compute_dtf(),
compute_duration(),
convert_date_to_dtm(),
convert_dtc_to_dt(),
convert_dtc_to_dtm(),
convert_xxtpt_to_hours(),
impute_dtc_dt(),
impute_dtc_dtm()
library(lubridate)
compute_tmf(dtc = "2019-07-18T15:25", dtm = ymd_hm("2019-07-18T15:25"))
compute_tmf(dtc = "2019-07-18T15", dtm = ymd_hm("2019-07-18T15:25"))
compute_tmf(dtc = "2019-07-18", dtm = ymd("2019-07-18"))
compute_tmf(dtc = "2022-05--T00:00", dtm = ymd_hm("2022-05-15T23:59"))
compute_tmf(dtc = "2022-05--T23:00", dtm = ymd_hm("2022-05-15T23:59"))
compute_tmf(
dtc = "2022-05--T23:59:00",
dtm = ymd_hms("2022-05-15T23:59:59"),
ignore_seconds_flag = FALSE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.