View source: R/derive_summary_records.R
| derive_summary_records | R Documentation |
It is not uncommon to have an analysis need whereby one needs to derive an
analysis value (AVAL) from multiple records. The ADaM basic dataset
structure variable DTYPE is available to indicate when a new derived
records has been added to a dataset, if the derivation deviates from the
standard derivation of the parameter.
derive_summary_records(
dataset = NULL,
dataset_add,
dataset_ref = NULL,
by_vars,
filter_add = NULL,
constant_values = NULL,
set_values_to,
missing_values = NULL
)
dataset |
Input dataset If the argument is not specified (or set to |
dataset_add |
Additional dataset The variables specified for |
dataset_ref |
Reference dataset The variables specified for |
by_vars |
Grouping variables Variables to consider for generation of groupwise summary
records. Providing the names of variables in |
filter_add |
Filter condition as logical expression to apply during
summary calculation. By default, filtering expressions are computed within
For example,
|
constant_values |
Constant variables to set The specified variables are set to the specified values for all new
summary records, including those with data in Set a list of variables to some specified value for the new records
|
set_values_to |
Variables to be set The specified variables are set to the specified values for the new observations. Set a list of variables to some specified value for the new records
For example: set_values_to = exprs(
AVAL = sum(AVAL),
DTYPE = "AVERAGE",
)
|
missing_values |
Values for missing summary values For observations of the reference dataset ( |
For the newly derived records, only variables specified within by_vars or
set_values_to will be populated. All other variables will be set to NA.
A data frame with derived records appended to original dataset.
derive_vars_merged_summary()
BDS-Findings Functions for adding Parameters/Records:
default_qtc_paramcd(),
derive_expected_records(),
derive_extreme_event(),
derive_extreme_records(),
derive_locf_records(),
derive_param_bmi(),
derive_param_bsa(),
derive_param_computed(),
derive_param_doseint(),
derive_param_exist_flag(),
derive_param_exposure(),
derive_param_framingham(),
derive_param_map(),
derive_param_qtc(),
derive_param_rr(),
derive_param_wbc_abs()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.