View source: R/derive_var_trtemfl.R
| derive_var_trtemfl | R Documentation |
Derive treatment emergent analysis flag (e.g., TRTEMFL).
derive_var_trtemfl(
dataset,
new_var = TRTEMFL,
start_date = ASTDTM,
end_date = AENDTM,
trt_start_date = TRTSDTM,
trt_end_date = NULL,
end_window = NULL,
ignore_time_for_trt_end = TRUE,
initial_intensity = NULL,
intensity = NULL,
group_var = NULL,
subject_keys = get_admiral_option("subject_keys")
)
dataset |
Input dataset The variables specified by |
new_var |
New variable |
start_date |
Event start date |
end_date |
Event end date |
trt_start_date |
Treatment start date |
trt_end_date |
Treatment end date |
end_window |
If the argument is specified (in 'days'), events starting more than the specified number of days after end of treatment, are not flagged. |
ignore_time_for_trt_end |
If the argument is set to |
initial_intensity |
Initial severity/intensity or toxicity
If this argument is specified and The values of the specified variable must be comparable with the usual
comparison operators. I.e., if the intensity is greater than the initial
intensity |
intensity |
Severity/intensity or toxicity If the argument is specified, events which start before treatment start and end after treatment start (or are ongoing) and worsened (i.e., the intensity is greater than the initial intensity), are flagged. The values of the specified variable must be comparable with the usual
comparison operators. I.e., if the intensity is greater than the initial
intensity |
group_var |
Grouping variable If the argument is specified, it assumes that AEs are recorded as one episode of AE with multiple lines using a grouping variable. Events starting during treatment or before treatment and worsening afterward are flagged. Once an AE record in a group is flagged, all subsequent records in the treatment window are flagged regardless of severity. |
subject_keys |
Variables to uniquely identify a subject. This argument is only used when |
For the derivation of the new variable the following cases are considered in this order. The first case which applies, defines the value of the variable.
not treated: If trt_start_date is NA, it is set to NA_character_.
event before treatment: If end_date is before trt_start_date (and
end_date is not NA), it is set to NA_character_.
no event date: If start_date is NA, it is set to "Y" as in such
cases it is usually considered more conservative to assume the event was
treatment-emergent.
event started during treatment:
if end_window is not specified:
if start_date is on or after trt_start_date, it is set to "Y",
if end_window is specified:
if start_date is on or after trt_start_date and start_date is on
or before trt_end_date + end_window days, it is set to "Y",
event started before treatment and (possibly) worsened on treatment:
if initial_intensity, intensity is specified and group_var is not specified:
if initial_intensity < intensity and start_date is before trt_start_date
and end_date is on or after trt_start_date or end_date is NA, it
is set to "Y";
if group_var is specified:
if intensity at treatment start < intensity and start_date is after
trt_start_date and end_date is on or after trt_start_date or
end_date is NA, it is set to "Y";
Otherwise it is set to NA_character_.
The behavior of derive_var_trtemfl() is aligned with the proposed
treatment-emergent AE assignment in the following
PHUSE White Paper.
See the final example in the examples section below.
The input dataset with the variable specified by new_var added
OCCDS Functions:
derive_vars_atc(),
derive_vars_query()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.